package com.sun.jmx.snmp;

import java.io.UnsupportedEncodingException;
import java.util.Objects;
import java.io.Serializable;

public class SnmpParameters extends SnmpParams implements Cloneable, Serializable
{
    private static final long serialVersionUID = -1822462497931733790L;
    static final String defaultRdCommunity = "public";
    private int _protocolVersion;
    private String _readCommunity;
    private String _writeCommunity;
    private String _informCommunity;
    
    public SnmpParameters() {
        this._protocolVersion = 0;
        this._readCommunity = "public";
        this._informCommunity = "public";
    }
    
    public SnmpParameters(String readCommunity, String writeCommunity) {
        this._protocolVersion = 0;
        this._readCommunity = readCommunity;
        this._writeCommunity = writeCommunity;
        this._informCommunity = "public";
    }
    
    public SnmpParameters(String readCommunity, String writeCommunity, String informCommunity) {
        this._protocolVersion = 0;
        this._readCommunity = readCommunity;
        this._writeCommunity = writeCommunity;
        this._informCommunity = informCommunity;
    }
    
    public String getRdCommunity() {
        return this._readCommunity;
    }
    
    public synchronized void setRdCommunity(String readCommunity) {
        if (readCommunity == null) {
            this._readCommunity = "public";
        }
        else {
            this._readCommunity = readCommunity;
        }
    }
    
    public String getWrCommunity() {
        return this._writeCommunity;
    }
    
    public void setWrCommunity(String writeCommunity) {
        this._writeCommunity = writeCommunity;
    }
    
    public String getInformCommunity() {
        return this._informCommunity;
    }
    
    public void setInformCommunity(String informCommunity) {
        if (informCommunity == null) {
            this._informCommunity = "public";
        }
        else {
            this._informCommunity = informCommunity;
        }
    }
    
    @Override
    public boolean allowSnmpSets() {
        return this._writeCommunity != null;
    }
    
    @Override
    public synchronized boolean equals(Object o) {
        if (!(o instanceof SnmpParameters)) {
            return false;
        }
        if (this == o) {
            return true;
        }
        SnmpParameters snmpParameters = (SnmpParameters)o;
        return this._protocolVersion == snmpParameters._protocolVersion && this._readCommunity.equals(snmpParameters._readCommunity);
    }
    
    @Override
    public synchronized int hashCode() {
        return this._protocolVersion * 31 ^ Objects.hashCode(this._readCommunity);
    }
    
    public synchronized Object clone() {
        SnmpParameters snmpParameters;
        try {
            snmpParameters = (SnmpParameters)super.clone();
            snmpParameters._readCommunity = this._readCommunity;
            snmpParameters._writeCommunity = this._writeCommunity;
            snmpParameters._informCommunity = this._informCommunity;
        }
        catch (CloneNotSupportedException ex) {
            throw new InternalError();
        }
        return snmpParameters;
    }
    
    public byte[] encodeAuthentication(int n) throws SnmpStatusException {
        try {
            if (n == 163) {
                return this._writeCommunity.getBytes("8859_1");
            }
            if (n == 166) {
                return this._informCommunity.getBytes("8859_1");
            }
            return this._readCommunity.getBytes("8859_1");
        }
        catch (UnsupportedEncodingException ex) {
            throw new SnmpStatusException(ex.getMessage());
        }
    }
}
